@@ -1,4 +1,6 @@
 
+## ----- Cells size plot -----
+
 #' @details `cellSizePlot()` plots the raw library size for each cell and
 #'   sample.
 #'
@@ -10,7 +12,7 @@
 #'   on the one indicated by `condName` that will only indicate the relevant
 #'   column name in the returned `data.frame`
 #'
-#' @returns `cellSizePlot()` returns the `violin-boxplot` plot
+#' @returns `cellSizePlot()` returns a `half-violin-boxplot` object
 #'
 #' @importFrom ggplot2 ggplot
 #' @importFrom ggplot2 geom_point
@@ -18,9 +20,10 @@
 #' @importFrom ggplot2 geom_boxplot
 #' @importFrom ggplot2 labs
 #' @importFrom ggplot2 scale_y_continuous
-#' @importFrom ggplot2 ylim
+#' @importFrom ggplot2 coord_cartesian
+#' @importFrom ggplot2 after_stat
 #'
-#' @importFrom gghalves geom_half_violin
+#' @importFrom ggdist stat_slabinterval
 #'
 #' @export
 #'
@@ -34,7 +37,7 @@ cellSizePlot <- function(objCOTAN, condName = "", conditions = NULL) {
   sizes <- sort(getCellsSize(objCOTAN))
   sizes <- as.data.frame(sizes)
 
-  sizes <- setColumnInDF(sizes, seq_len(nrow(sizes)), colName = "n")
+  sizes <- setColumnInDF(sizes, colToSet = seq_len(nrow(sizes)), colName = "n")
 
   c(., conditions) %<-%
     normalizeNameAndLabels(objCOTAN, name = condName,
@@ -46,25 +49,43 @@ cellSizePlot <- function(objCOTAN, condName = "", conditions = NULL) {
   plot <-
     sizes %>%
     ggplot(aes(x = sample, y = sizes, fill = sample)) +
-    #geom_point(size = 0.5) +
-    geom_half_violin(side = "r", position = position_nudge(x = 0.15),
-                     adjust = 2.0, alpha = 0.5, trim = TRUE) +
-    geom_point(position = position_jitter(width = 0.1),
-               size = 0.4, color = "black", alpha = 0.5) +
-    geom_boxplot(aes(x = sample, y = sizes, fill = sample),
-                 outlier.shape = NA, alpha = 0.8, width = 0.15,
-                 colour = "gray65", size = 0.6) +
-    labs(title = "Cell library size",
-         y = "Size (read number)",
-         x = "") +
-    # scale_y_continuous(expand = c(0L, 0L)) +
-    ylim(0.0, max(sizes[["sizes"]])) +
+    stat_slabinterval(
+      aes(thickness = after_stat(pdf)),
+      side = "right",                   # draw only the right half
+      show_point = FALSE,               # slab only (no dot)
+      show_interval = FALSE,            # slab only (no interval)
+      position = position_nudge(x = 0.15),
+      normalize = "groups",
+      adjust = 2.0,
+      trim = TRUE,
+      alpha = 0.5,
+      slab_colour = "black",      # outline color
+      slab_linewidth = 0.6,       # outline width (ggplot2 ≥ 3.4)
+      slab_alpha = 0.5            # fill alpha only; leaves stroke opaque
+    ) +
+    geom_point(
+      position = position_jitter(width = 0.1),
+      size = 0.4, color = "black", alpha = 0.5
+    ) +
+    geom_boxplot(
+      aes(x = sample, y = sizes, fill = sample),
+      outlier.shape = NA, alpha = 0.8, width = 0.15,
+      colour = "gray65", size = 0.6
+    ) +
+    labs(
+      title = "Cell library size",
+      y = "Size (read number)",
+      x = ""
+    ) +
+    coord_cartesian(ylim = c(0.0, max(sizes[["sizes"]]))) +
     plotTheme("size-plot")
 
   return(plot)
 }
 
 
+## ----- Genes size plot -----
+
 #' @details `genesSizePlot()` plots the raw gene number (reads > 0) for each
 #'   cell and sample
 #'
@@ -76,7 +97,7 @@ cellSizePlot <- function(objCOTAN, condName = "", conditions = NULL) {
 #'   on the one indicated by `condName` that will only indicate the relevant
 #'   column name in the returned `data.frame`
 #'
-#' @returns `genesSizePlot()` returns the `violin-boxplot` plot
+#' @returns `genesSizePlot()` returns a `half-violin-boxplot` object
 #'
 #' @importFrom ggplot2 ggplot
 #' @importFrom ggplot2 position_nudge
@@ -86,9 +107,10 @@ cellSizePlot <- function(objCOTAN, condName = "", conditions = NULL) {
 #' @importFrom ggplot2 aes
 #' @importFrom ggplot2 labs
 #' @importFrom ggplot2 scale_y_continuous
-#' @importFrom ggplot2 ylim
+#' @importFrom ggplot2 coord_cartesian
+#' @importFrom ggplot2 after_stat
 #'
-#' @importFrom gghalves geom_half_violin
+#' @importFrom ggdist stat_slabinterval
 #'
 #' @export
 #'
@@ -114,19 +136,35 @@ genesSizePlot <- function(objCOTAN, condName = "", conditions = NULL) {
   plot <-
     sizes %>%
     ggplot(aes(x = sample, y = sizes, fill = sample)) +
-    #geom_point(size = 0.5) +
-    geom_half_violin(side = "r", position = position_nudge(x = 0.15),
-                     adjust = 2.0, alpha = 0.5, trim = TRUE) +
-    geom_point(position = position_jitter(width = 0.1),
-               size = 0.4, color = "black", alpha = 0.5) +
-    geom_boxplot(aes(x = sample, y = sizes, fill = sample),
-                 outlier.shape = NA, alpha = 0.8, width = 0.15,
-                 colour = "gray65", size = 0.6) +
-    labs(title = "Detected gene number",
-         y = "Size (number of genes)",
-         x = "") +
-    # scale_y_continuous(expand = c(0L, 0L)) +
-    ylim(0L, max(sizes[["sizes"]])) +
+    stat_slabinterval(
+      aes(thickness = after_stat(pdf)),
+      side = "right",                 # half-violin to the right
+      show_point = FALSE,             # slab only
+      show_interval = FALSE,          # no intervals
+      position = position_nudge(x = 0.15),
+      normalize = "groups",
+      adjust = 2.0,
+      trim = TRUE,
+      alpha = 0.5,
+      slab_colour = "black",      # outline color
+      slab_linewidth = 0.6,       # outline width (ggplot2 ≥ 3.4)
+      slab_alpha = 0.5            # fill alpha only; leaves stroke opaque
+    ) +
+    geom_point(
+      position = position_jitter(width = 0.1),
+      size = 0.4, color = "black", alpha = 0.5
+    ) +
+    geom_boxplot(
+      aes(x = sample, y = sizes, fill = sample),
+      outlier.shape = NA, alpha = 0.8, width = 0.15,
+      colour = "gray65", size = 0.6
+    ) +
+    labs(
+      title = "Detected gene number",
+      y = "Size (number of genes)",
+      x = ""
+    ) +
+    coord_cartesian(ylim = c(0.0, max(sizes[["sizes"]]))) +
     plotTheme("size-plot")
 
   return(plot)
